@@ -1,19 +1,18 @@
-"""The player state module includes an enum which represents the player
-state. For example, if a player is in the pot with the proper amount
-of chips, that player is said to be IN. If a player needs to call a bet,
-that player has status TO_CALL. If a player has no more chips to bet,
-that player is ALL_IN, etc."""
-
 from enum import Enum, auto
 
 
 class PlayerState(Enum):
-    """An enum representing a player state (i.e. needs to
-    call, in the pot, sitting out, etc."""
+    """
+    Player state Enum. For example, if a player is in the pot with the proper amount
+    of chips, that player is said to be :obj:`PlayerState.IN`. If a player needs to call a bet,
+    that player has status :obj:`PlayerState.TO_CALL`. If a player has no more chips to bet,
+    that player is :obj:`PlayerState.ALL_IN`, etc.
+
+    """
 
     SKIP = auto()
     """Player is sitting out this hand, they will not be dealt
-    cards and will rejoin upon request."""
+    cards and will rejoin upon request. Will be implemented in a future version."""
 
     OUT = auto()
     """Player has folded their hand this round."""
